==> igniteui-react-charts-16.15.1.tgz: package/esm5/lib/igr-stacked-bar-series.js <==
import { __extends } from "tslib";
import { IgrVerticalStackedSeriesBase } from "./igr-vertical-stacked-series-base";
import { StackedBarSeries } from "./StackedBarSeries";
import { toPoint } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent stacked bar series.
*/
var IgrStackedBarSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrStackedBarSeries, _super);
    function IgrStackedBarSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrStackedBarSeries.prototype.createImplementation = function () {
        return new StackedBarSeries();
    };
    Object.defineProperty(IgrStackedBarSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedBarSeries.prototype, "isBar", {
        /**
         * Gets whether the current series shows a bar shape.
        */
        get: function () {
            return this.i.db;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedBarSeries.prototype, "isMarkerlessDisplayPreferred", {
        /**
         * Overridden by derived series classes to indicate when marker-less display is preferred or not.
        */
        get: function () {
            return this.i.dy;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedBarSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the bar.
        */
        get: function () {
            return this.i.ua;
        },
        set: function (v) {
            this.i.ua = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedBarSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the bar.
        */
        get: function () {
            return this.i.ub;
        },
        set: function (v) {
            this.i.ub = +v;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    IgrStackedBarSeries.prototype.scrollIntoView = function (item) {
        var iv = this.i.ej(item);
        return (iv);
    };
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    IgrStackedBarSeries.prototype.getItemIndex = function (world) {
        var iv = this.i.g3(toPoint(world));
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    IgrStackedBarSeries.prototype.getItem = function (world) {
        var iv = this.i.hk(toPoint(world));
        return (iv);
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrStackedBarSeries.prototype.getItemSpan = function () {
        var iv = this.i.f3();
        return (iv);
    };
    return IgrStackedBarSeries;
}(IgrVerticalStackedSeriesBase));
export { IgrStackedBarSeries };

==> igniteui-react-charts-16.16.3.tgz: package/esm5/lib/igr-stacked-bar-series.js <==
import { __extends } from "tslib";
import { IgrVerticalStackedSeriesBase } from "./igr-vertical-stacked-series-base";
import { StackedBarSeries } from "./StackedBarSeries";
import { toPoint } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent stacked bar series.
*/
var IgrStackedBarSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrStackedBarSeries, _super);
    function IgrStackedBarSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrStackedBarSeries.prototype.createImplementation = function () {
        return new StackedBarSeries();
    };
    Object.defineProperty(IgrStackedBarSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedBarSeries.prototype, "isBar", {
        /**
         * Gets whether the current series shows a bar shape.
        */
        get: function () {
            return this.i.df;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedBarSeries.prototype, "isMarkerlessDisplayPreferred", {
        /**
         * Overridden by derived series classes to indicate when marker-less display is preferred or not.
        */
        get: function () {
            return this.i.d2;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedBarSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the bar.
        */
        get: function () {
            return this.i.un;
        },
        set: function (v) {
            this.i.un = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedBarSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the bar.
        */
        get: function () {
            return this.i.uo;
        },
        set: function (v) {
            this.i.uo = +v;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    IgrStackedBarSeries.prototype.scrollIntoView = function (item) {
        var iv = this.i.en(item);
        return (iv);
    };
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    IgrStackedBarSeries.prototype.getItemIndex = function (world) {
        var iv = this.i.hd(toPoint(world));
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    IgrStackedBarSeries.prototype.getItem = function (world) {
        var iv = this.i.ht(toPoint(world));
        return (iv);
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrStackedBarSeries.prototype.getItemSpan = function () {
        var iv = this.i.ga();
        return (iv);
    };
    return IgrStackedBarSeries;
}(IgrVerticalStackedSeriesBase));
export { IgrStackedBarSeries };
